# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookCollectionResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'response_status': 'int',
        'total_results': 'int',
        'returned_results': 'int',
        'data': 'list[Webhook]',
        'included': 'list[AnyOfWebhookCollectionResponseIncludedItems]'
    }

    attribute_map = {
        'response_status': 'responseStatus',
        'total_results': 'totalResults',
        'returned_results': 'returnedResults',
        'data': 'data',
        'included': 'included'
    }

    def __init__(self, response_status=None, total_results=None, returned_results=None, data=None, included=None):  # noqa: E501
        """WebhookCollectionResponse - a model defined in Swagger"""  # noqa: E501
        self._response_status = None
        self._total_results = None
        self._returned_results = None
        self._data = None
        self._included = None
        self.discriminator = None
        if response_status is not None:
            self.response_status = response_status
        if total_results is not None:
            self.total_results = total_results
        if returned_results is not None:
            self.returned_results = returned_results
        if data is not None:
            self.data = data
        if included is not None:
            self.included = included

    @property
    def response_status(self):
        """Gets the response_status of this WebhookCollectionResponse.  # noqa: E501

        Http status code of the response.   # noqa: E501

        :return: The response_status of this WebhookCollectionResponse.  # noqa: E501
        :rtype: int
        """
        return self._response_status

    @response_status.setter
    def response_status(self, response_status):
        """Sets the response_status of this WebhookCollectionResponse.

        Http status code of the response.   # noqa: E501

        :param response_status: The response_status of this WebhookCollectionResponse.  # noqa: E501
        :type: int
        """

        self._response_status = response_status

    @property
    def total_results(self):
        """Gets the total_results of this WebhookCollectionResponse.  # noqa: E501

        Total results found.  # noqa: E501

        :return: The total_results of this WebhookCollectionResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_results

    @total_results.setter
    def total_results(self, total_results):
        """Sets the total_results of this WebhookCollectionResponse.

        Total results found.  # noqa: E501

        :param total_results: The total_results of this WebhookCollectionResponse.  # noqa: E501
        :type: int
        """

        self._total_results = total_results

    @property
    def returned_results(self):
        """Gets the returned_results of this WebhookCollectionResponse.  # noqa: E501

        Number of results returned.  # noqa: E501

        :return: The returned_results of this WebhookCollectionResponse.  # noqa: E501
        :rtype: int
        """
        return self._returned_results

    @returned_results.setter
    def returned_results(self, returned_results):
        """Sets the returned_results of this WebhookCollectionResponse.

        Number of results returned.  # noqa: E501

        :param returned_results: The returned_results of this WebhookCollectionResponse.  # noqa: E501
        :type: int
        """

        self._returned_results = returned_results

    @property
    def data(self):
        """Gets the data of this WebhookCollectionResponse.  # noqa: E501


        :return: The data of this WebhookCollectionResponse.  # noqa: E501
        :rtype: list[Webhook]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this WebhookCollectionResponse.


        :param data: The data of this WebhookCollectionResponse.  # noqa: E501
        :type: list[Webhook]
        """

        self._data = data

    @property
    def included(self):
        """Gets the included of this WebhookCollectionResponse.  # noqa: E501


        :return: The included of this WebhookCollectionResponse.  # noqa: E501
        :rtype: list[AnyOfWebhookCollectionResponseIncludedItems]
        """
        return self._included

    @included.setter
    def included(self, included):
        """Sets the included of this WebhookCollectionResponse.


        :param included: The included of this WebhookCollectionResponse.  # noqa: E501
        :type: list[AnyOfWebhookCollectionResponseIncludedItems]
        """

        self._included = included

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookCollectionResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookCollectionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PlanDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'storage_add_on': 'int',
        'ip_whitelist': 'bool',
        'user_expiration': 'bool',
        'user_import': 'bool',
        'custom_domain': 'bool',
        'custom_name': 'bool',
        'color_schema': 'bool',
        'api_keys': 'int',
        'api_tokens': 'int',
        'ssh_keys': 'int',
        'direct_links': 'bool',
        'sharing_options': 'list[str]',
        'webhook_options': 'PlanDetailsWebhookOptions',
        'unlimited_users': 'bool'
    }

    attribute_map = {
        'storage_add_on': 'storageAddOn',
        'ip_whitelist': 'ipWhitelist',
        'user_expiration': 'userExpiration',
        'user_import': 'userImport',
        'custom_domain': 'customDomain',
        'custom_name': 'customName',
        'color_schema': 'colorSchema',
        'api_keys': 'apiKeys',
        'api_tokens': 'apiTokens',
        'ssh_keys': 'sshKeys',
        'direct_links': 'directLinks',
        'sharing_options': 'sharingOptions',
        'webhook_options': 'webhookOptions',
        'unlimited_users': 'unlimitedUsers'
    }

    def __init__(self, storage_add_on=None, ip_whitelist=None, user_expiration=None, user_import=None, custom_domain=None, custom_name=None, color_schema=None, api_keys=None, api_tokens=None, ssh_keys=None, direct_links=None, sharing_options=None, webhook_options=None, unlimited_users=None):  # noqa: E501
        """PlanDetails - a model defined in Swagger"""  # noqa: E501
        self._storage_add_on = None
        self._ip_whitelist = None
        self._user_expiration = None
        self._user_import = None
        self._custom_domain = None
        self._custom_name = None
        self._color_schema = None
        self._api_keys = None
        self._api_tokens = None
        self._ssh_keys = None
        self._direct_links = None
        self._sharing_options = None
        self._webhook_options = None
        self._unlimited_users = None
        self.discriminator = None
        if storage_add_on is not None:
            self.storage_add_on = storage_add_on
        if ip_whitelist is not None:
            self.ip_whitelist = ip_whitelist
        if user_expiration is not None:
            self.user_expiration = user_expiration
        if user_import is not None:
            self.user_import = user_import
        if custom_domain is not None:
            self.custom_domain = custom_domain
        if custom_name is not None:
            self.custom_name = custom_name
        if color_schema is not None:
            self.color_schema = color_schema
        if api_keys is not None:
            self.api_keys = api_keys
        if api_tokens is not None:
            self.api_tokens = api_tokens
        if ssh_keys is not None:
            self.ssh_keys = ssh_keys
        if direct_links is not None:
            self.direct_links = direct_links
        if sharing_options is not None:
            self.sharing_options = sharing_options
        if webhook_options is not None:
            self.webhook_options = webhook_options
        if unlimited_users is not None:
            self.unlimited_users = unlimited_users

    @property
    def storage_add_on(self):
        """Gets the storage_add_on of this PlanDetails.  # noqa: E501


        :return: The storage_add_on of this PlanDetails.  # noqa: E501
        :rtype: int
        """
        return self._storage_add_on

    @storage_add_on.setter
    def storage_add_on(self, storage_add_on):
        """Sets the storage_add_on of this PlanDetails.


        :param storage_add_on: The storage_add_on of this PlanDetails.  # noqa: E501
        :type: int
        """

        self._storage_add_on = storage_add_on

    @property
    def ip_whitelist(self):
        """Gets the ip_whitelist of this PlanDetails.  # noqa: E501


        :return: The ip_whitelist of this PlanDetails.  # noqa: E501
        :rtype: bool
        """
        return self._ip_whitelist

    @ip_whitelist.setter
    def ip_whitelist(self, ip_whitelist):
        """Sets the ip_whitelist of this PlanDetails.


        :param ip_whitelist: The ip_whitelist of this PlanDetails.  # noqa: E501
        :type: bool
        """

        self._ip_whitelist = ip_whitelist

    @property
    def user_expiration(self):
        """Gets the user_expiration of this PlanDetails.  # noqa: E501


        :return: The user_expiration of this PlanDetails.  # noqa: E501
        :rtype: bool
        """
        return self._user_expiration

    @user_expiration.setter
    def user_expiration(self, user_expiration):
        """Sets the user_expiration of this PlanDetails.


        :param user_expiration: The user_expiration of this PlanDetails.  # noqa: E501
        :type: bool
        """

        self._user_expiration = user_expiration

    @property
    def user_import(self):
        """Gets the user_import of this PlanDetails.  # noqa: E501


        :return: The user_import of this PlanDetails.  # noqa: E501
        :rtype: bool
        """
        return self._user_import

    @user_import.setter
    def user_import(self, user_import):
        """Sets the user_import of this PlanDetails.


        :param user_import: The user_import of this PlanDetails.  # noqa: E501
        :type: bool
        """

        self._user_import = user_import

    @property
    def custom_domain(self):
        """Gets the custom_domain of this PlanDetails.  # noqa: E501


        :return: The custom_domain of this PlanDetails.  # noqa: E501
        :rtype: bool
        """
        return self._custom_domain

    @custom_domain.setter
    def custom_domain(self, custom_domain):
        """Sets the custom_domain of this PlanDetails.


        :param custom_domain: The custom_domain of this PlanDetails.  # noqa: E501
        :type: bool
        """

        self._custom_domain = custom_domain

    @property
    def custom_name(self):
        """Gets the custom_name of this PlanDetails.  # noqa: E501


        :return: The custom_name of this PlanDetails.  # noqa: E501
        :rtype: bool
        """
        return self._custom_name

    @custom_name.setter
    def custom_name(self, custom_name):
        """Sets the custom_name of this PlanDetails.


        :param custom_name: The custom_name of this PlanDetails.  # noqa: E501
        :type: bool
        """

        self._custom_name = custom_name

    @property
    def color_schema(self):
        """Gets the color_schema of this PlanDetails.  # noqa: E501


        :return: The color_schema of this PlanDetails.  # noqa: E501
        :rtype: bool
        """
        return self._color_schema

    @color_schema.setter
    def color_schema(self, color_schema):
        """Sets the color_schema of this PlanDetails.


        :param color_schema: The color_schema of this PlanDetails.  # noqa: E501
        :type: bool
        """

        self._color_schema = color_schema

    @property
    def api_keys(self):
        """Gets the api_keys of this PlanDetails.  # noqa: E501


        :return: The api_keys of this PlanDetails.  # noqa: E501
        :rtype: int
        """
        return self._api_keys

    @api_keys.setter
    def api_keys(self, api_keys):
        """Sets the api_keys of this PlanDetails.


        :param api_keys: The api_keys of this PlanDetails.  # noqa: E501
        :type: int
        """

        self._api_keys = api_keys

    @property
    def api_tokens(self):
        """Gets the api_tokens of this PlanDetails.  # noqa: E501


        :return: The api_tokens of this PlanDetails.  # noqa: E501
        :rtype: int
        """
        return self._api_tokens

    @api_tokens.setter
    def api_tokens(self, api_tokens):
        """Sets the api_tokens of this PlanDetails.


        :param api_tokens: The api_tokens of this PlanDetails.  # noqa: E501
        :type: int
        """

        self._api_tokens = api_tokens

    @property
    def ssh_keys(self):
        """Gets the ssh_keys of this PlanDetails.  # noqa: E501


        :return: The ssh_keys of this PlanDetails.  # noqa: E501
        :rtype: int
        """
        return self._ssh_keys

    @ssh_keys.setter
    def ssh_keys(self, ssh_keys):
        """Sets the ssh_keys of this PlanDetails.


        :param ssh_keys: The ssh_keys of this PlanDetails.  # noqa: E501
        :type: int
        """

        self._ssh_keys = ssh_keys

    @property
    def direct_links(self):
        """Gets the direct_links of this PlanDetails.  # noqa: E501


        :return: The direct_links of this PlanDetails.  # noqa: E501
        :rtype: bool
        """
        return self._direct_links

    @direct_links.setter
    def direct_links(self, direct_links):
        """Sets the direct_links of this PlanDetails.


        :param direct_links: The direct_links of this PlanDetails.  # noqa: E501
        :type: bool
        """

        self._direct_links = direct_links

    @property
    def sharing_options(self):
        """Gets the sharing_options of this PlanDetails.  # noqa: E501


        :return: The sharing_options of this PlanDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._sharing_options

    @sharing_options.setter
    def sharing_options(self, sharing_options):
        """Sets the sharing_options of this PlanDetails.


        :param sharing_options: The sharing_options of this PlanDetails.  # noqa: E501
        :type: list[str]
        """

        self._sharing_options = sharing_options

    @property
    def webhook_options(self):
        """Gets the webhook_options of this PlanDetails.  # noqa: E501


        :return: The webhook_options of this PlanDetails.  # noqa: E501
        :rtype: PlanDetailsWebhookOptions
        """
        return self._webhook_options

    @webhook_options.setter
    def webhook_options(self, webhook_options):
        """Sets the webhook_options of this PlanDetails.


        :param webhook_options: The webhook_options of this PlanDetails.  # noqa: E501
        :type: PlanDetailsWebhookOptions
        """

        self._webhook_options = webhook_options

    @property
    def unlimited_users(self):
        """Gets the unlimited_users of this PlanDetails.  # noqa: E501


        :return: The unlimited_users of this PlanDetails.  # noqa: E501
        :rtype: bool
        """
        return self._unlimited_users

    @unlimited_users.setter
    def unlimited_users(self, unlimited_users):
        """Sets the unlimited_users of this PlanDetails.


        :param unlimited_users: The unlimited_users of this PlanDetails.  # noqa: E501
        :type: bool
        """

        self._unlimited_users = unlimited_users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlanDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlanDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AccountQuotaValues(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'notice_enabled': 'bool',
        'notice_threshold': 'int',
        'transactions_notice_enabled': 'bool',
        'transactions_notice_threshold': 'int'
    }

    attribute_map = {
        'notice_enabled': 'noticeEnabled',
        'notice_threshold': 'noticeThreshold',
        'transactions_notice_enabled': 'transactionsNoticeEnabled',
        'transactions_notice_threshold': 'transactionsNoticeThreshold'
    }

    def __init__(self, notice_enabled=None, notice_threshold=None, transactions_notice_enabled=None, transactions_notice_threshold=None):  # noqa: E501
        """AccountQuotaValues - a model defined in Swagger"""  # noqa: E501
        self._notice_enabled = None
        self._notice_threshold = None
        self._transactions_notice_enabled = None
        self._transactions_notice_threshold = None
        self.discriminator = None
        if notice_enabled is not None:
            self.notice_enabled = notice_enabled
        if notice_threshold is not None:
            self.notice_threshold = notice_threshold
        if transactions_notice_enabled is not None:
            self.transactions_notice_enabled = transactions_notice_enabled
        if transactions_notice_threshold is not None:
            self.transactions_notice_threshold = transactions_notice_threshold

    @property
    def notice_enabled(self):
        """Gets the notice_enabled of this AccountQuotaValues.  # noqa: E501

        Whether the system should email the account owner if the account storage exceeds the noticeThreshold value. Storage notice emails are sent no mo once per day.  # noqa: E501

        :return: The notice_enabled of this AccountQuotaValues.  # noqa: E501
        :rtype: bool
        """
        return self._notice_enabled

    @notice_enabled.setter
    def notice_enabled(self, notice_enabled):
        """Sets the notice_enabled of this AccountQuotaValues.

        Whether the system should email the account owner if the account storage exceeds the noticeThreshold value. Storage notice emails are sent no mo once per day.  # noqa: E501

        :param notice_enabled: The notice_enabled of this AccountQuotaValues.  # noqa: E501
        :type: bool
        """

        self._notice_enabled = notice_enabled

    @property
    def notice_threshold(self):
        """Gets the notice_threshold of this AccountQuotaValues.  # noqa: E501

        Percent of account storage that would trigger a notice email. Must be a whole number between 70 and 100 (inclusive).  # noqa: E501

        :return: The notice_threshold of this AccountQuotaValues.  # noqa: E501
        :rtype: int
        """
        return self._notice_threshold

    @notice_threshold.setter
    def notice_threshold(self, notice_threshold):
        """Sets the notice_threshold of this AccountQuotaValues.

        Percent of account storage that would trigger a notice email. Must be a whole number between 70 and 100 (inclusive).  # noqa: E501

        :param notice_threshold: The notice_threshold of this AccountQuotaValues.  # noqa: E501
        :type: int
        """

        self._notice_threshold = notice_threshold

    @property
    def transactions_notice_enabled(self):
        """Gets the transactions_notice_enabled of this AccountQuotaValues.  # noqa: E501

        Whether the system should email the account owner if the daily transaction usage exceeds the transactionsNoticeThreshold value. Transaction notice emails are sent no more than once per day.  # noqa: E501

        :return: The transactions_notice_enabled of this AccountQuotaValues.  # noqa: E501
        :rtype: bool
        """
        return self._transactions_notice_enabled

    @transactions_notice_enabled.setter
    def transactions_notice_enabled(self, transactions_notice_enabled):
        """Sets the transactions_notice_enabled of this AccountQuotaValues.

        Whether the system should email the account owner if the daily transaction usage exceeds the transactionsNoticeThreshold value. Transaction notice emails are sent no more than once per day.  # noqa: E501

        :param transactions_notice_enabled: The transactions_notice_enabled of this AccountQuotaValues.  # noqa: E501
        :type: bool
        """

        self._transactions_notice_enabled = transactions_notice_enabled

    @property
    def transactions_notice_threshold(self):
        """Gets the transactions_notice_threshold of this AccountQuotaValues.  # noqa: E501

        Percent of daily transaction usage that would trigger a notice email. Must be a whole number between 70 and 100 (inclusive).  # noqa: E501

        :return: The transactions_notice_threshold of this AccountQuotaValues.  # noqa: E501
        :rtype: int
        """
        return self._transactions_notice_threshold

    @transactions_notice_threshold.setter
    def transactions_notice_threshold(self, transactions_notice_threshold):
        """Sets the transactions_notice_threshold of this AccountQuotaValues.

        Percent of daily transaction usage that would trigger a notice email. Must be a whole number between 70 and 100 (inclusive).  # noqa: E501

        :param transactions_notice_threshold: The transactions_notice_threshold of this AccountQuotaValues.  # noqa: E501
        :type: int
        """

        self._transactions_notice_threshold = transactions_notice_threshold

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccountQuotaValues, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountQuotaValues):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateWebhookRequestBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'endpoint_url': 'str',
        'triggers': 'WebhookTriggers',
        'resource': 'str',
        'response_version': 'str'
    }

    attribute_map = {
        'endpoint_url': 'endpointUrl',
        'triggers': 'triggers',
        'resource': 'resource',
        'response_version': 'responseVersion'
    }

    def __init__(self, endpoint_url=None, triggers=None, resource=None, response_version=None):  # noqa: E501
        """UpdateWebhookRequestBody - a model defined in Swagger"""  # noqa: E501
        self._endpoint_url = None
        self._triggers = None
        self._resource = None
        self._response_version = None
        self.discriminator = None
        if endpoint_url is not None:
            self.endpoint_url = endpoint_url
        if triggers is not None:
            self.triggers = triggers
        if resource is not None:
            self.resource = resource
        if response_version is not None:
            self.response_version = response_version

    @property
    def endpoint_url(self):
        """Gets the endpoint_url of this UpdateWebhookRequestBody.  # noqa: E501

        New endpoint URL to use for the webhook configuration  # noqa: E501

        :return: The endpoint_url of this UpdateWebhookRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_url

    @endpoint_url.setter
    def endpoint_url(self, endpoint_url):
        """Sets the endpoint_url of this UpdateWebhookRequestBody.

        New endpoint URL to use for the webhook configuration  # noqa: E501

        :param endpoint_url: The endpoint_url of this UpdateWebhookRequestBody.  # noqa: E501
        :type: str
        """

        self._endpoint_url = endpoint_url

    @property
    def triggers(self):
        """Gets the triggers of this UpdateWebhookRequestBody.  # noqa: E501


        :return: The triggers of this UpdateWebhookRequestBody.  # noqa: E501
        :rtype: WebhookTriggers
        """
        return self._triggers

    @triggers.setter
    def triggers(self, triggers):
        """Sets the triggers of this UpdateWebhookRequestBody.


        :param triggers: The triggers of this UpdateWebhookRequestBody.  # noqa: E501
        :type: WebhookTriggers
        """

        self._triggers = triggers

    @property
    def resource(self):
        """Gets the resource of this UpdateWebhookRequestBody.  # noqa: E501

        Resource identifier of the top folder watched by this webhook.  # noqa: E501

        :return: The resource of this UpdateWebhookRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this UpdateWebhookRequestBody.

        Resource identifier of the top folder watched by this webhook.  # noqa: E501

        :param resource: The resource of this UpdateWebhookRequestBody.  # noqa: E501
        :type: str
        """

        self._resource = resource

    @property
    def response_version(self):
        """Gets the response_version of this UpdateWebhookRequestBody.  # noqa: E501

        Version of the webhooks message to send to the endpoint  # noqa: E501

        :return: The response_version of this UpdateWebhookRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._response_version

    @response_version.setter
    def response_version(self, response_version):
        """Sets the response_version of this UpdateWebhookRequestBody.

        Version of the webhooks message to send to the endpoint  # noqa: E501

        :param response_version: The response_version of this UpdateWebhookRequestBody.  # noqa: E501
        :type: str
        """
        allowed_values = ["v2", "v1"]  # noqa: E501
        if response_version not in allowed_values:
            raise ValueError(
                "Invalid value for `response_version` ({0}), must be one of {1}"  # noqa: E501
                .format(response_version, allowed_values)
            )

        self._response_version = response_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateWebhookRequestBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateWebhookRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookTriggersResources(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'upload': 'bool',
        'download': 'bool',
        'delete': 'bool',
        'rename': 'bool',
        'copy': 'bool',
        'move': 'bool',
        'compress': 'bool',
        'extract': 'bool',
        'create_folder': 'bool'
    }

    attribute_map = {
        'upload': 'upload',
        'download': 'download',
        'delete': 'delete',
        'rename': 'rename',
        'copy': 'copy',
        'move': 'move',
        'compress': 'compress',
        'extract': 'extract',
        'create_folder': 'createFolder'
    }

    def __init__(self, upload=None, download=None, delete=None, rename=None, copy=None, move=None, compress=None, extract=None, create_folder=None):  # noqa: E501
        """WebhookTriggersResources - a model defined in Swagger"""  # noqa: E501
        self._upload = None
        self._download = None
        self._delete = None
        self._rename = None
        self._copy = None
        self._move = None
        self._compress = None
        self._extract = None
        self._create_folder = None
        self.discriminator = None
        if upload is not None:
            self.upload = upload
        if download is not None:
            self.download = download
        if delete is not None:
            self.delete = delete
        if rename is not None:
            self.rename = rename
        if copy is not None:
            self.copy = copy
        if move is not None:
            self.move = move
        if compress is not None:
            self.compress = compress
        if extract is not None:
            self.extract = extract
        if create_folder is not None:
            self.create_folder = create_folder

    @property
    def upload(self):
        """Gets the upload of this WebhookTriggersResources.  # noqa: E501

        Send webhook messages when resources are uploaded.  # noqa: E501

        :return: The upload of this WebhookTriggersResources.  # noqa: E501
        :rtype: bool
        """
        return self._upload

    @upload.setter
    def upload(self, upload):
        """Sets the upload of this WebhookTriggersResources.

        Send webhook messages when resources are uploaded.  # noqa: E501

        :param upload: The upload of this WebhookTriggersResources.  # noqa: E501
        :type: bool
        """

        self._upload = upload

    @property
    def download(self):
        """Gets the download of this WebhookTriggersResources.  # noqa: E501

        Send webhook messages when resources are downloaded.  # noqa: E501

        :return: The download of this WebhookTriggersResources.  # noqa: E501
        :rtype: bool
        """
        return self._download

    @download.setter
    def download(self, download):
        """Sets the download of this WebhookTriggersResources.

        Send webhook messages when resources are downloaded.  # noqa: E501

        :param download: The download of this WebhookTriggersResources.  # noqa: E501
        :type: bool
        """

        self._download = download

    @property
    def delete(self):
        """Gets the delete of this WebhookTriggersResources.  # noqa: E501

        Send webhook messages when resources are deleted  # noqa: E501

        :return: The delete of this WebhookTriggersResources.  # noqa: E501
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this WebhookTriggersResources.

        Send webhook messages when resources are deleted  # noqa: E501

        :param delete: The delete of this WebhookTriggersResources.  # noqa: E501
        :type: bool
        """

        self._delete = delete

    @property
    def rename(self):
        """Gets the rename of this WebhookTriggersResources.  # noqa: E501

        Send webhook messages when resources are renamed.  # noqa: E501

        :return: The rename of this WebhookTriggersResources.  # noqa: E501
        :rtype: bool
        """
        return self._rename

    @rename.setter
    def rename(self, rename):
        """Sets the rename of this WebhookTriggersResources.

        Send webhook messages when resources are renamed.  # noqa: E501

        :param rename: The rename of this WebhookTriggersResources.  # noqa: E501
        :type: bool
        """

        self._rename = rename

    @property
    def copy(self):
        """Gets the copy of this WebhookTriggersResources.  # noqa: E501

        Send webhook messages when resources are copied.  # noqa: E501

        :return: The copy of this WebhookTriggersResources.  # noqa: E501
        :rtype: bool
        """
        return self._copy

    @copy.setter
    def copy(self, copy):
        """Sets the copy of this WebhookTriggersResources.

        Send webhook messages when resources are copied.  # noqa: E501

        :param copy: The copy of this WebhookTriggersResources.  # noqa: E501
        :type: bool
        """

        self._copy = copy

    @property
    def move(self):
        """Gets the move of this WebhookTriggersResources.  # noqa: E501

        Send webhook messages when resources are moved.  # noqa: E501

        :return: The move of this WebhookTriggersResources.  # noqa: E501
        :rtype: bool
        """
        return self._move

    @move.setter
    def move(self, move):
        """Sets the move of this WebhookTriggersResources.

        Send webhook messages when resources are moved.  # noqa: E501

        :param move: The move of this WebhookTriggersResources.  # noqa: E501
        :type: bool
        """

        self._move = move

    @property
    def compress(self):
        """Gets the compress of this WebhookTriggersResources.  # noqa: E501

        Send webhook messages when resources are compressed into an archive.  # noqa: E501

        :return: The compress of this WebhookTriggersResources.  # noqa: E501
        :rtype: bool
        """
        return self._compress

    @compress.setter
    def compress(self, compress):
        """Sets the compress of this WebhookTriggersResources.

        Send webhook messages when resources are compressed into an archive.  # noqa: E501

        :param compress: The compress of this WebhookTriggersResources.  # noqa: E501
        :type: bool
        """

        self._compress = compress

    @property
    def extract(self):
        """Gets the extract of this WebhookTriggersResources.  # noqa: E501

        Send webhook messages when resources are extracted from an archive.  # noqa: E501

        :return: The extract of this WebhookTriggersResources.  # noqa: E501
        :rtype: bool
        """
        return self._extract

    @extract.setter
    def extract(self, extract):
        """Sets the extract of this WebhookTriggersResources.

        Send webhook messages when resources are extracted from an archive.  # noqa: E501

        :param extract: The extract of this WebhookTriggersResources.  # noqa: E501
        :type: bool
        """

        self._extract = extract

    @property
    def create_folder(self):
        """Gets the create_folder of this WebhookTriggersResources.  # noqa: E501

        Send webhook messages when a new folder is created.  # noqa: E501

        :return: The create_folder of this WebhookTriggersResources.  # noqa: E501
        :rtype: bool
        """
        return self._create_folder

    @create_folder.setter
    def create_folder(self, create_folder):
        """Sets the create_folder of this WebhookTriggersResources.

        Send webhook messages when a new folder is created.  # noqa: E501

        :param create_folder: The create_folder of this WebhookTriggersResources.  # noqa: E501
        :type: bool
        """

        self._create_folder = create_folder

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookTriggersResources, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookTriggersResources):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Error(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'str',
        'title': 'str',
        'detail': 'str',
        'meta': 'object'
    }

    attribute_map = {
        'code': 'code',
        'title': 'title',
        'detail': 'detail',
        'meta': 'meta'
    }

    def __init__(self, code=None, title=None, detail=None, meta=None):  # noqa: E501
        """Error - a model defined in Swagger"""  # noqa: E501
        self._code = None
        self._title = None
        self._detail = None
        self._meta = None
        self.discriminator = None
        if code is not None:
            self.code = code
        if title is not None:
            self.title = title
        if detail is not None:
            self.detail = detail
        if meta is not None:
            self.meta = meta

    @property
    def code(self):
        """Gets the code of this Error.  # noqa: E501

        Specific internal error string.  # noqa: E501

        :return: The code of this Error.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Error.

        Specific internal error string.  # noqa: E501

        :param code: The code of this Error.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def title(self):
        """Gets the title of this Error.  # noqa: E501

        Human readable summary of the problem.  # noqa: E501

        :return: The title of this Error.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Error.

        Human readable summary of the problem.  # noqa: E501

        :param title: The title of this Error.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def detail(self):
        """Gets the detail of this Error.  # noqa: E501

        human-readable explanation specific to this occurrence of the problem.  # noqa: E501

        :return: The detail of this Error.  # noqa: E501
        :rtype: str
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this Error.

        human-readable explanation specific to this occurrence of the problem.  # noqa: E501

        :param detail: The detail of this Error.  # noqa: E501
        :type: str
        """

        self._detail = detail

    @property
    def meta(self):
        """Gets the meta of this Error.  # noqa: E501

        Meta object containing non-standard meta-information about the error.  # noqa: E501

        :return: The meta of this Error.  # noqa: E501
        :rtype: object
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this Error.

        Meta object containing non-standard meta-information about the error.  # noqa: E501

        :param meta: The meta of this Error.  # noqa: E501
        :type: object
        """

        self._meta = meta

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Error, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SSHKeyAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fingerprint': 'str',
        'last_login': 'datetime',
        'created': 'datetime'
    }

    attribute_map = {
        'fingerprint': 'fingerprint',
        'last_login': 'lastLogin',
        'created': 'created'
    }

    def __init__(self, fingerprint=None, last_login=None, created=None):  # noqa: E501
        """SSHKeyAttributes - a model defined in Swagger"""  # noqa: E501
        self._fingerprint = None
        self._last_login = None
        self._created = None
        self.discriminator = None
        if fingerprint is not None:
            self.fingerprint = fingerprint
        if last_login is not None:
            self.last_login = last_login
        if created is not None:
            self.created = created

    @property
    def fingerprint(self):
        """Gets the fingerprint of this SSHKeyAttributes.  # noqa: E501

        The Key Fingerprint. The fingerprint can be used to identify and keep track of the key without exposing the actual credential.   # noqa: E501

        :return: The fingerprint of this SSHKeyAttributes.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this SSHKeyAttributes.

        The Key Fingerprint. The fingerprint can be used to identify and keep track of the key without exposing the actual credential.   # noqa: E501

        :param fingerprint: The fingerprint of this SSHKeyAttributes.  # noqa: E501
        :type: str
        """

        self._fingerprint = fingerprint

    @property
    def last_login(self):
        """Gets the last_login of this SSHKeyAttributes.  # noqa: E501

        The date-time the SSH Key was last used to access ExaVault.   # noqa: E501

        :return: The last_login of this SSHKeyAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._last_login

    @last_login.setter
    def last_login(self, last_login):
        """Sets the last_login of this SSHKeyAttributes.

        The date-time the SSH Key was last used to access ExaVault.   # noqa: E501

        :param last_login: The last_login of this SSHKeyAttributes.  # noqa: E501
        :type: datetime
        """

        self._last_login = last_login

    @property
    def created(self):
        """Gets the created of this SSHKeyAttributes.  # noqa: E501

        The date-time the SSH Key was created.  # noqa: E501

        :return: The created of this SSHKeyAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this SSHKeyAttributes.

        The date-time the SSH Key was created.  # noqa: E501

        :param created: The created of this SSHKeyAttributes.  # noqa: E501
        :type: datetime
        """

        self._created = created

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SSHKeyAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SSHKeyAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SessionActivityEntry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'type': 'str',
        'attributes': 'SessionActivityEntryAttributes'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'attributes': 'attributes'
    }

    def __init__(self, id=None, type=None, attributes=None):  # noqa: E501
        """SessionActivityEntry - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._type = None
        self._attributes = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if attributes is not None:
            self.attributes = attributes

    @property
    def id(self):
        """Gets the id of this SessionActivityEntry.  # noqa: E501


        :return: The id of this SessionActivityEntry.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SessionActivityEntry.


        :param id: The id of this SessionActivityEntry.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this SessionActivityEntry.  # noqa: E501


        :return: The type of this SessionActivityEntry.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SessionActivityEntry.


        :param type: The type of this SessionActivityEntry.  # noqa: E501
        :type: str
        """
        allowed_values = ["sessionActivity"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def attributes(self):
        """Gets the attributes of this SessionActivityEntry.  # noqa: E501


        :return: The attributes of this SessionActivityEntry.  # noqa: E501
        :rtype: SessionActivityEntryAttributes
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this SessionActivityEntry.


        :param attributes: The attributes of this SessionActivityEntry.  # noqa: E501
        :type: SessionActivityEntryAttributes
        """

        self._attributes = attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SessionActivityEntry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SessionActivityEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'endpoint_url': 'str',
        'failed': 'bool',
        'verification_token': 'str',
        'response_version': 'str',
        'triggers': 'WebhookTriggers',
        'created': 'datetime',
        'modified': 'datetime'
    }

    attribute_map = {
        'endpoint_url': 'endpointUrl',
        'failed': 'failed',
        'verification_token': 'verificationToken',
        'response_version': 'responseVersion',
        'triggers': 'triggers',
        'created': 'created',
        'modified': 'modified'
    }

    def __init__(self, endpoint_url=None, failed=None, verification_token=None, response_version=None, triggers=None, created=None, modified=None):  # noqa: E501
        """WebhookAttributes - a model defined in Swagger"""  # noqa: E501
        self._endpoint_url = None
        self._failed = None
        self._verification_token = None
        self._response_version = None
        self._triggers = None
        self._created = None
        self._modified = None
        self.discriminator = None
        if endpoint_url is not None:
            self.endpoint_url = endpoint_url
        if failed is not None:
            self.failed = failed
        if verification_token is not None:
            self.verification_token = verification_token
        if response_version is not None:
            self.response_version = response_version
        if triggers is not None:
            self.triggers = triggers
        if created is not None:
            self.created = created
        if modified is not None:
            self.modified = modified

    @property
    def endpoint_url(self):
        """Gets the endpoint_url of this WebhookAttributes.  # noqa: E501

        The endpoint is where the webhook request will be sent.  # noqa: E501

        :return: The endpoint_url of this WebhookAttributes.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_url

    @endpoint_url.setter
    def endpoint_url(self, endpoint_url):
        """Sets the endpoint_url of this WebhookAttributes.

        The endpoint is where the webhook request will be sent.  # noqa: E501

        :param endpoint_url: The endpoint_url of this WebhookAttributes.  # noqa: E501
        :type: str
        """

        self._endpoint_url = endpoint_url

    @property
    def failed(self):
        """Gets the failed of this WebhookAttributes.  # noqa: E501

        Whether webhook has been disabled for too many consecutive failures  # noqa: E501

        :return: The failed of this WebhookAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._failed

    @failed.setter
    def failed(self, failed):
        """Sets the failed of this WebhookAttributes.

        Whether webhook has been disabled for too many consecutive failures  # noqa: E501

        :param failed: The failed of this WebhookAttributes.  # noqa: E501
        :type: bool
        """

        self._failed = failed

    @property
    def verification_token(self):
        """Gets the verification_token of this WebhookAttributes.  # noqa: E501

        Token for verifying sender is ExaVault  # noqa: E501

        :return: The verification_token of this WebhookAttributes.  # noqa: E501
        :rtype: str
        """
        return self._verification_token

    @verification_token.setter
    def verification_token(self, verification_token):
        """Sets the verification_token of this WebhookAttributes.

        Token for verifying sender is ExaVault  # noqa: E501

        :param verification_token: The verification_token of this WebhookAttributes.  # noqa: E501
        :type: str
        """

        self._verification_token = verification_token

    @property
    def response_version(self):
        """Gets the response_version of this WebhookAttributes.  # noqa: E501

        The version of webhook request to send to the endpoint URL  # noqa: E501

        :return: The response_version of this WebhookAttributes.  # noqa: E501
        :rtype: str
        """
        return self._response_version

    @response_version.setter
    def response_version(self, response_version):
        """Sets the response_version of this WebhookAttributes.

        The version of webhook request to send to the endpoint URL  # noqa: E501

        :param response_version: The response_version of this WebhookAttributes.  # noqa: E501
        :type: str
        """
        allowed_values = ["v1", "v2"]  # noqa: E501
        if response_version not in allowed_values:
            raise ValueError(
                "Invalid value for `response_version` ({0}), must be one of {1}"  # noqa: E501
                .format(response_version, allowed_values)
            )

        self._response_version = response_version

    @property
    def triggers(self):
        """Gets the triggers of this WebhookAttributes.  # noqa: E501


        :return: The triggers of this WebhookAttributes.  # noqa: E501
        :rtype: WebhookTriggers
        """
        return self._triggers

    @triggers.setter
    def triggers(self, triggers):
        """Sets the triggers of this WebhookAttributes.


        :param triggers: The triggers of this WebhookAttributes.  # noqa: E501
        :type: WebhookTriggers
        """

        self._triggers = triggers

    @property
    def created(self):
        """Gets the created of this WebhookAttributes.  # noqa: E501

        Timestamp when webhook configuration was added to system.  # noqa: E501

        :return: The created of this WebhookAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this WebhookAttributes.

        Timestamp when webhook configuration was added to system.  # noqa: E501

        :param created: The created of this WebhookAttributes.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this WebhookAttributes.  # noqa: E501

        Timestamp when webhook configuration was last modified  # noqa: E501

        :return: The modified of this WebhookAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this WebhookAttributes.

        Timestamp when webhook configuration was last modified  # noqa: E501

        :param modified: The modified of this WebhookAttributes.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from exavault.api_client import ApiClient


class SSHKeysApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_ssh_key(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Create a new SSH Key  # noqa: E501

        Create a new SSH Key for a user. Provide the Public Key as formatted from the ssh-keygen command (openssh format or RFC-4716 format).  If you'd prefer to let us generate your key automatically, you can log in to your account via the web portal and set up new keys via the SSH Keys page.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_ssh_key(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param AddSSHKeyRequestBody body:
        :return: SSHKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_ssh_key_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.add_ssh_key_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def add_ssh_key_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Create a new SSH Key  # noqa: E501

        Create a new SSH Key for a user. Provide the Public Key as formatted from the ssh-keygen command (openssh format or RFC-4716 format).  If you'd prefer to let us generate your key automatically, you can log in to your account via the web portal and set up new keys via the SSH Keys page.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_ssh_key_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param AddSSHKeyRequestBody body:
        :return: SSHKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_ssh_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `add_ssh_key`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `add_ssh_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ssh-keys', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SSHKeyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_ssh_key(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Delete an SSH Key  # noqa: E501

        Delete the specified SSH key. This will not delete or deactivate the user tied to the key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ssh_key(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_ssh_key_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_ssh_key_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def delete_ssh_key_with_http_info(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Delete an SSH Key  # noqa: E501

        Delete the specified SSH key. This will not delete or deactivate the user tied to the key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ssh_key_with_http_info(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'ev_api_key', 'ev_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_ssh_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_ssh_key`")  # noqa: E501
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `delete_ssh_key`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `delete_ssh_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ssh-keys/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ssh_key(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get metadata for an SSH Key  # noqa: E501

        Return the information for a single SSH Key  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ssh_key(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: SSHKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ssh_key_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ssh_key_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def get_ssh_key_with_http_info(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get metadata for an SSH Key  # noqa: E501

        Return the information for a single SSH Key  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ssh_key_with_http_info(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: SSHKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'ev_api_key', 'ev_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ssh_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_ssh_key`")  # noqa: E501
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `get_ssh_key`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `get_ssh_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ssh-keys/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SSHKeyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ssh_keys_list(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get metadata for a list of SSH Keys  # noqa: E501

        Returns a list of SSH Keys within the account. Can be filtered for a single user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ssh_keys_list(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str user_id:  Only return results for the given user ID. This is not the username, but the numeric ID of the user.
        :param int limit:  Limits the results by the given number. Cannot be set higher than 100.
        :param int offset:  Determines which item to start on for pagination. Use zero (0) to start at the beginning of the list.
        :return: SSHKeyCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ssh_keys_list_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ssh_keys_list_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def get_ssh_keys_list_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get metadata for a list of SSH Keys  # noqa: E501

        Returns a list of SSH Keys within the account. Can be filtered for a single user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ssh_keys_list_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str user_id:  Only return results for the given user ID. This is not the username, but the numeric ID of the user.
        :param int limit:  Limits the results by the given number. Cannot be set higher than 100.
        :param int offset:  Determines which item to start on for pagination. Use zero (0) to start at the beginning of the list.
        :return: SSHKeyCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'user_id', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ssh_keys_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `get_ssh_keys_list`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `get_ssh_keys_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_id' in params:
            query_params.append(('userId', params['user_id']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ssh-keys', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SSHKeyCollectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from exavault.api_client import ApiClient


class WebhooksApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_webhook(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Add A New Webhook  # noqa: E501

        Create a new Webhook on your account. Creating a Webhook will require an endpoint URL, a path, what events should trigger a webhook, and what request version to use.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_webhook(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param AddWebhookRequestBody body:
        :return: WebhookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_webhook_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.add_webhook_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def add_webhook_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Add A New Webhook  # noqa: E501

        Create a new Webhook on your account. Creating a Webhook will require an endpoint URL, a path, what events should trigger a webhook, and what request version to use.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_webhook_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param AddWebhookRequestBody body:
        :return: WebhookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_webhook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `add_webhook`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `add_webhook`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/webhooks', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebhookResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_webhook(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Delete a webhook  # noqa: E501

        Deleted the specified webhook. This will not affect logs or any resources the webhook is connected to.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_webhook(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: Webhook endpoint ID (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_webhook_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_webhook_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def delete_webhook_with_http_info(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Delete a webhook  # noqa: E501

        Deleted the specified webhook. This will not affect logs or any resources the webhook is connected to.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_webhook_with_http_info(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: Webhook endpoint ID (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'ev_api_key', 'ev_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_webhook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_webhook`")  # noqa: E501
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `delete_webhook`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `delete_webhook`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/webhooks/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_webhook_by_id(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get info for a webhook  # noqa: E501

        Returns the metadata for a specific webhook. Webhook IDs can be retrieve from GET /webhooks  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webhook_by_id(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: Webhook endpoint ID (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str include:  Include metadata for related items; `ownerAccount` and/or `resource` 
        :return: WebhookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_webhook_by_id_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_webhook_by_id_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def get_webhook_by_id_with_http_info(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get info for a webhook  # noqa: E501

        Returns the metadata for a specific webhook. Webhook IDs can be retrieve from GET /webhooks  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webhook_by_id_with_http_info(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: Webhook endpoint ID (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str include:  Include metadata for related items; `ownerAccount` and/or `resource` 
        :return: WebhookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'ev_api_key', 'ev_access_token', 'include']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webhook_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_webhook_by_id`")  # noqa: E501
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `get_webhook_by_id`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `get_webhook_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'include' in params:
            query_params.append(('include', params['include']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/webhooks/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebhookResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_wehooks_list(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get Webhooks List  # noqa: E501

        Returns a list of Webhooks. By default, this will return metadata on all Webhooks within the account.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wehooks_list(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str include: List of related record types to include. Valid options are `owningAccount` and `resource`
        :param int offset: Records to skip before returning results.
        :param int limit: Limit of the records list
        :return: WebhookCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_wehooks_list_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_wehooks_list_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def get_wehooks_list_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get Webhooks List  # noqa: E501

        Returns a list of Webhooks. By default, this will return metadata on all Webhooks within the account.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wehooks_list_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param str include: List of related record types to include. Valid options are `owningAccount` and `resource`
        :param int offset: Records to skip before returning results.
        :param int limit: Limit of the records list
        :return: WebhookCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'include', 'offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_wehooks_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `get_wehooks_list`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `get_wehooks_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'include' in params:
            query_params.append(('include', params['include']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/webhooks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebhookCollectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def regenerate_webhook_token(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Regenerate security token  # noqa: E501

        This endpoint will allow you to regenerate the security token for a webhook if you believe it’s been compromised in any way.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.regenerate_webhook_token(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Webhook ID (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: WebhookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.regenerate_webhook_token_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.regenerate_webhook_token_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def regenerate_webhook_token_with_http_info(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Regenerate security token  # noqa: E501

        This endpoint will allow you to regenerate the security token for a webhook if you believe it’s been compromised in any way.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.regenerate_webhook_token_with_http_info(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Webhook ID (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: WebhookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'ev_api_key', 'ev_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method regenerate_webhook_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `regenerate_webhook_token`")  # noqa: E501
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `regenerate_webhook_token`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `regenerate_webhook_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/webhooks/regenerate-token/{id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebhookResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resend_webhook_activity_entry(self, activity_id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Resend a webhook message  # noqa: E501

        This endpoint will allow you to resend a webhook that was previously sent. Resent webhooks will send exactly the same as the original webhook with the exception of the “sent” timestamp. Activity IDs can be retrieve from the webhook logs in your account or via GET /activity/webhooks  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resend_webhook_activity_entry(activity_id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_id: Webhooks activity entry ID (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resend_webhook_activity_entry_with_http_info(activity_id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.resend_webhook_activity_entry_with_http_info(activity_id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def resend_webhook_activity_entry_with_http_info(self, activity_id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Resend a webhook message  # noqa: E501

        This endpoint will allow you to resend a webhook that was previously sent. Resent webhooks will send exactly the same as the original webhook with the exception of the “sent” timestamp. Activity IDs can be retrieve from the webhook logs in your account or via GET /activity/webhooks  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resend_webhook_activity_entry_with_http_info(activity_id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_id: Webhooks activity entry ID (required)
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_id', 'ev_api_key', 'ev_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resend_webhook_activity_entry" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_id' is set
        if ('activity_id' not in params or
                params['activity_id'] is None):
            raise ValueError("Missing the required parameter `activity_id` when calling `resend_webhook_activity_entry`")  # noqa: E501
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `resend_webhook_activity_entry`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `resend_webhook_activity_entry`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_id' in params:
            path_params['activityId'] = params['activity_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/webhooks/resend/{activityId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_webhook(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Update a webhook  # noqa: E501

        Update the specified webhook. Updated webhooks will take effect immediately and could impact active workflows. Please be certain the webhook is not currently in use prior to updating.   You only need to send the portions of the webhook configuration you wish to change, rather than the entire webhook object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_webhook(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: Webhook endpoint ID (required)
        :param UpdateWebhookRequestBody body:
        :return: WebhookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_webhook_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_webhook_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
            return data

    def update_webhook_with_http_info(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Update a webhook  # noqa: E501

        Update the specified webhook. Updated webhooks will take effect immediately and could impact active workflows. Please be certain the webhook is not currently in use prior to updating.   You only need to send the portions of the webhook configuration you wish to change, rather than the entire webhook object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_webhook_with_http_info(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int id: Webhook endpoint ID (required)
        :param UpdateWebhookRequestBody body:
        :return: WebhookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_webhook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `update_webhook`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `update_webhook`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_webhook`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/webhooks/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebhookResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookActivityAttributesV2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'webhook_id': 'int',
        'webhook_format': 'str',
        'attempt_id': 'str',
        'account_id': 'str',
        'resend': 'bool',
        'endpoint_url': 'str',
        'event': 'str',
        'status': 'int',
        'ip_address': 'str',
        'response': 'str',
        'details': 'WebhookV2Details',
        'webhook_path': 'str',
        '_resource_path': 'str',
        'username': 'str',
        'created': 'str'
    }

    attribute_map = {
        'webhook_id': 'webhookId',
        'webhook_format': 'webhookFormat',
        'attempt_id': 'attemptId',
        'account_id': 'accountId',
        'resend': 'resend',
        'endpoint_url': 'endpointUrl',
        'event': 'event',
        'status': 'status',
        'ip_address': 'ipAddress',
        'response': 'response',
        'details': 'details',
        'webhook_path': 'webhookPath',
        '_resource_path': 'resourcePath',
        'username': 'username',
        'created': 'created'
    }

    def __init__(self, webhook_id=None, webhook_format=None, attempt_id=None, account_id=None, resend=None, endpoint_url=None, event=None, status=None, ip_address=None, response=None, details=None, webhook_path=None, _resource_path=None, username=None, created=None):  # noqa: E501
        """WebhookActivityAttributesV2 - a model defined in Swagger"""  # noqa: E501
        self._webhook_id = None
        self._webhook_format = None
        self._attempt_id = None
        self._account_id = None
        self._resend = None
        self._endpoint_url = None
        self._event = None
        self._status = None
        self._ip_address = None
        self._response = None
        self._details = None
        self._webhook_path = None
        self.__resource_path = None
        self._username = None
        self._created = None
        self.discriminator = None
        if webhook_id is not None:
            self.webhook_id = webhook_id
        if webhook_format is not None:
            self.webhook_format = webhook_format
        if attempt_id is not None:
            self.attempt_id = attempt_id
        if account_id is not None:
            self.account_id = account_id
        if resend is not None:
            self.resend = resend
        if endpoint_url is not None:
            self.endpoint_url = endpoint_url
        if event is not None:
            self.event = event
        if status is not None:
            self.status = status
        if ip_address is not None:
            self.ip_address = ip_address
        if response is not None:
            self.response = response
        if details is not None:
            self.details = details
        if webhook_path is not None:
            self.webhook_path = webhook_path
        if _resource_path is not None:
            self._resource_path = _resource_path
        if username is not None:
            self.username = username
        if created is not None:
            self.created = created

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookActivityAttributesV2.  # noqa: E501

        Unique ID of webhook configuration  # noqa: E501

        :return: The webhook_id of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: int
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookActivityAttributesV2.

        Unique ID of webhook configuration  # noqa: E501

        :param webhook_id: The webhook_id of this WebhookActivityAttributesV2.  # noqa: E501
        :type: int
        """

        self._webhook_id = webhook_id

    @property
    def webhook_format(self):
        """Gets the webhook_format of this WebhookActivityAttributesV2.  # noqa: E501

        What version of webhook message is being sent `v2`  # noqa: E501

        :return: The webhook_format of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self._webhook_format

    @webhook_format.setter
    def webhook_format(self, webhook_format):
        """Sets the webhook_format of this WebhookActivityAttributesV2.

        What version of webhook message is being sent `v2`  # noqa: E501

        :param webhook_format: The webhook_format of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """

        self._webhook_format = webhook_format

    @property
    def attempt_id(self):
        """Gets the attempt_id of this WebhookActivityAttributesV2.  # noqa: E501

        Event - retry identifier  # noqa: E501

        :return: The attempt_id of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self._attempt_id

    @attempt_id.setter
    def attempt_id(self, attempt_id):
        """Sets the attempt_id of this WebhookActivityAttributesV2.

        Event - retry identifier  # noqa: E501

        :param attempt_id: The attempt_id of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """

        self._attempt_id = attempt_id

    @property
    def account_id(self):
        """Gets the account_id of this WebhookActivityAttributesV2.  # noqa: E501

        Unique ID of account  # noqa: E501

        :return: The account_id of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this WebhookActivityAttributesV2.

        Unique ID of account  # noqa: E501

        :param account_id: The account_id of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def resend(self):
        """Gets the resend of this WebhookActivityAttributesV2.  # noqa: E501

        Whether this attempt was a re-send of a previous attempt  # noqa: E501

        :return: The resend of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: bool
        """
        return self._resend

    @resend.setter
    def resend(self, resend):
        """Sets the resend of this WebhookActivityAttributesV2.

        Whether this attempt was a re-send of a previous attempt  # noqa: E501

        :param resend: The resend of this WebhookActivityAttributesV2.  # noqa: E501
        :type: bool
        """

        self._resend = resend

    @property
    def endpoint_url(self):
        """Gets the endpoint_url of this WebhookActivityAttributesV2.  # noqa: E501

        The URL the message was sent to  # noqa: E501

        :return: The endpoint_url of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_url

    @endpoint_url.setter
    def endpoint_url(self, endpoint_url):
        """Sets the endpoint_url of this WebhookActivityAttributesV2.

        The URL the message was sent to  # noqa: E501

        :param endpoint_url: The endpoint_url of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """

        self._endpoint_url = endpoint_url

    @property
    def event(self):
        """Gets the event of this WebhookActivityAttributesV2.  # noqa: E501

        Event type  # noqa: E501

        :return: The event of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this WebhookActivityAttributesV2.

        Event type  # noqa: E501

        :param event: The event of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """
        allowed_values = ["resources.upload", "resources.download", "resources.delete", "resources.rename", "resources.copy", "resources.move", "resources.compress", "resources.extract", "resources.createFolder", "shares.formSubmit"]  # noqa: E501
        if event not in allowed_values:
            raise ValueError(
                "Invalid value for `event` ({0}), must be one of {1}"  # noqa: E501
                .format(event, allowed_values)
            )

        self._event = event

    @property
    def status(self):
        """Gets the status of this WebhookActivityAttributesV2.  # noqa: E501

        HTTP Status Code returned by webhook listener  # noqa: E501

        :return: The status of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WebhookActivityAttributesV2.

        HTTP Status Code returned by webhook listener  # noqa: E501

        :param status: The status of this WebhookActivityAttributesV2.  # noqa: E501
        :type: int
        """

        self._status = status

    @property
    def ip_address(self):
        """Gets the ip_address of this WebhookActivityAttributesV2.  # noqa: E501

        IP Address of related activity  # noqa: E501

        :return: The ip_address of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this WebhookActivityAttributesV2.

        IP Address of related activity  # noqa: E501

        :param ip_address: The ip_address of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def response(self):
        """Gets the response of this WebhookActivityAttributesV2.  # noqa: E501

        Body of web response returned by webhook listener  # noqa: E501

        :return: The response of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self._response

    @response.setter
    def response(self, response):
        """Sets the response of this WebhookActivityAttributesV2.

        Body of web response returned by webhook listener  # noqa: E501

        :param response: The response of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """

        self._response = response

    @property
    def details(self):
        """Gets the details of this WebhookActivityAttributesV2.  # noqa: E501


        :return: The details of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: WebhookV2Details
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this WebhookActivityAttributesV2.


        :param details: The details of this WebhookActivityAttributesV2.  # noqa: E501
        :type: WebhookV2Details
        """

        self._details = details

    @property
    def webhook_path(self):
        """Gets the webhook_path of this WebhookActivityAttributesV2.  # noqa: E501

        Path that webhook is watching  # noqa: E501

        :return: The webhook_path of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self._webhook_path

    @webhook_path.setter
    def webhook_path(self, webhook_path):
        """Sets the webhook_path of this WebhookActivityAttributesV2.

        Path that webhook is watching  # noqa: E501

        :param webhook_path: The webhook_path of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """

        self._webhook_path = webhook_path

    @property
    def _resource_path(self):
        """Gets the _resource_path of this WebhookActivityAttributesV2.  # noqa: E501

        Path of resource that matched webhook  # noqa: E501

        :return: The _resource_path of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self.__resource_path

    @_resource_path.setter
    def _resource_path(self, _resource_path):
        """Sets the _resource_path of this WebhookActivityAttributesV2.

        Path of resource that matched webhook  # noqa: E501

        :param _resource_path: The _resource_path of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """

        self.__resource_path = _resource_path

    @property
    def username(self):
        """Gets the username of this WebhookActivityAttributesV2.  # noqa: E501

        Username of related activity  # noqa: E501

        :return: The username of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this WebhookActivityAttributesV2.

        Username of related activity  # noqa: E501

        :param username: The username of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def created(self):
        """Gets the created of this WebhookActivityAttributesV2.  # noqa: E501

        Date and time of webhook message being generated by system  # noqa: E501

        :return: The created of this WebhookActivityAttributesV2.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this WebhookActivityAttributesV2.

        Date and time of webhook message being generated by system  # noqa: E501

        :param created: The created of this WebhookActivityAttributesV2.  # noqa: E501
        :type: str
        """

        self._created = created

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookActivityAttributesV2, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookActivityAttributesV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookV2EventData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resources': 'list[WebhookV2EventDataResources]',
        'form_details': 'list[object]',
        'share': 'list[WebhookV2EventDataShare]',
        'transfer_status': 'str'
    }

    attribute_map = {
        'resources': 'resources',
        'form_details': 'formDetails',
        'share': 'share',
        'transfer_status': 'transferStatus'
    }

    def __init__(self, resources=None, form_details=None, share=None, transfer_status=None):  # noqa: E501
        """WebhookV2EventData - a model defined in Swagger"""  # noqa: E501
        self._resources = None
        self._form_details = None
        self._share = None
        self._transfer_status = None
        self.discriminator = None
        if resources is not None:
            self.resources = resources
        if form_details is not None:
            self.form_details = form_details
        if share is not None:
            self.share = share
        if transfer_status is not None:
            self.transfer_status = transfer_status

    @property
    def resources(self):
        """Gets the resources of this WebhookV2EventData.  # noqa: E501


        :return: The resources of this WebhookV2EventData.  # noqa: E501
        :rtype: list[WebhookV2EventDataResources]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this WebhookV2EventData.


        :param resources: The resources of this WebhookV2EventData.  # noqa: E501
        :type: list[WebhookV2EventDataResources]
        """

        self._resources = resources

    @property
    def form_details(self):
        """Gets the form_details of this WebhookV2EventData.  # noqa: E501


        :return: The form_details of this WebhookV2EventData.  # noqa: E501
        :rtype: list[object]
        """
        return self._form_details

    @form_details.setter
    def form_details(self, form_details):
        """Sets the form_details of this WebhookV2EventData.


        :param form_details: The form_details of this WebhookV2EventData.  # noqa: E501
        :type: list[object]
        """

        self._form_details = form_details

    @property
    def share(self):
        """Gets the share of this WebhookV2EventData.  # noqa: E501


        :return: The share of this WebhookV2EventData.  # noqa: E501
        :rtype: list[WebhookV2EventDataShare]
        """
        return self._share

    @share.setter
    def share(self, share):
        """Sets the share of this WebhookV2EventData.


        :param share: The share of this WebhookV2EventData.  # noqa: E501
        :type: list[WebhookV2EventDataShare]
        """

        self._share = share

    @property
    def transfer_status(self):
        """Gets the transfer_status of this WebhookV2EventData.  # noqa: E501

        For uploads, and downloads, whether the file transferred OK. `success` means the transfer did not have errors  # noqa: E501

        :return: The transfer_status of this WebhookV2EventData.  # noqa: E501
        :rtype: str
        """
        return self._transfer_status

    @transfer_status.setter
    def transfer_status(self, transfer_status):
        """Sets the transfer_status of this WebhookV2EventData.

        For uploads, and downloads, whether the file transferred OK. `success` means the transfer did not have errors  # noqa: E501

        :param transfer_status: The transfer_status of this WebhookV2EventData.  # noqa: E501
        :type: str
        """

        self._transfer_status = transfer_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookV2EventData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookV2EventData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookV2Details(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attempt_id': 'str',
        'account_name': 'str',
        'event_timestamp': 'datetime',
        'ip_address': 'str',
        'protocol': 'str',
        'username': 'str',
        'event': 'str',
        'event_data': 'WebhookV2EventData'
    }

    attribute_map = {
        'attempt_id': 'attemptId',
        'account_name': 'accountName',
        'event_timestamp': 'eventTimestamp',
        'ip_address': 'ipAddress',
        'protocol': 'protocol',
        'username': 'username',
        'event': 'event',
        'event_data': 'eventData'
    }

    def __init__(self, attempt_id=None, account_name=None, event_timestamp=None, ip_address=None, protocol=None, username=None, event=None, event_data=None):  # noqa: E501
        """WebhookV2Details - a model defined in Swagger"""  # noqa: E501
        self._attempt_id = None
        self._account_name = None
        self._event_timestamp = None
        self._ip_address = None
        self._protocol = None
        self._username = None
        self._event = None
        self._event_data = None
        self.discriminator = None
        if attempt_id is not None:
            self.attempt_id = attempt_id
        if account_name is not None:
            self.account_name = account_name
        if event_timestamp is not None:
            self.event_timestamp = event_timestamp
        if ip_address is not None:
            self.ip_address = ip_address
        if protocol is not None:
            self.protocol = protocol
        if username is not None:
            self.username = username
        if event is not None:
            self.event = event
        if event_data is not None:
            self.event_data = event_data

    @property
    def attempt_id(self):
        """Gets the attempt_id of this WebhookV2Details.  # noqa: E501

        Entry - retry identifier  # noqa: E501

        :return: The attempt_id of this WebhookV2Details.  # noqa: E501
        :rtype: str
        """
        return self._attempt_id

    @attempt_id.setter
    def attempt_id(self, attempt_id):
        """Sets the attempt_id of this WebhookV2Details.

        Entry - retry identifier  # noqa: E501

        :param attempt_id: The attempt_id of this WebhookV2Details.  # noqa: E501
        :type: str
        """

        self._attempt_id = attempt_id

    @property
    def account_name(self):
        """Gets the account_name of this WebhookV2Details.  # noqa: E501

        Account master username  # noqa: E501

        :return: The account_name of this WebhookV2Details.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this WebhookV2Details.

        Account master username  # noqa: E501

        :param account_name: The account_name of this WebhookV2Details.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def event_timestamp(self):
        """Gets the event_timestamp of this WebhookV2Details.  # noqa: E501

        Date and time event originally took place  # noqa: E501

        :return: The event_timestamp of this WebhookV2Details.  # noqa: E501
        :rtype: datetime
        """
        return self._event_timestamp

    @event_timestamp.setter
    def event_timestamp(self, event_timestamp):
        """Sets the event_timestamp of this WebhookV2Details.

        Date and time event originally took place  # noqa: E501

        :param event_timestamp: The event_timestamp of this WebhookV2Details.  # noqa: E501
        :type: datetime
        """

        self._event_timestamp = event_timestamp

    @property
    def ip_address(self):
        """Gets the ip_address of this WebhookV2Details.  # noqa: E501

        IP address of related activity  # noqa: E501

        :return: The ip_address of this WebhookV2Details.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this WebhookV2Details.

        IP address of related activity  # noqa: E501

        :param ip_address: The ip_address of this WebhookV2Details.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def protocol(self):
        """Gets the protocol of this WebhookV2Details.  # noqa: E501

        Type of connection used for related activity  # noqa: E501

        :return: The protocol of this WebhookV2Details.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this WebhookV2Details.

        Type of connection used for related activity  # noqa: E501

        :param protocol: The protocol of this WebhookV2Details.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    @property
    def username(self):
        """Gets the username of this WebhookV2Details.  # noqa: E501

        Username logged for related activity. May refer to someone who is not a user of the account, such as a share recipient or \"publ  # noqa: E501

        :return: The username of this WebhookV2Details.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this WebhookV2Details.

        Username logged for related activity. May refer to someone who is not a user of the account, such as a share recipient or \"publ  # noqa: E501

        :param username: The username of this WebhookV2Details.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def event(self):
        """Gets the event of this WebhookV2Details.  # noqa: E501

        Type of related activity  # noqa: E501

        :return: The event of this WebhookV2Details.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this WebhookV2Details.

        Type of related activity  # noqa: E501

        :param event: The event of this WebhookV2Details.  # noqa: E501
        :type: str
        """

        self._event = event

    @property
    def event_data(self):
        """Gets the event_data of this WebhookV2Details.  # noqa: E501


        :return: The event_data of this WebhookV2Details.  # noqa: E501
        :rtype: WebhookV2EventData
        """
        return self._event_data

    @event_data.setter
    def event_data(self, event_data):
        """Sets the event_data of this WebhookV2Details.


        :param event_data: The event_data of this WebhookV2Details.  # noqa: E501
        :type: WebhookV2EventData
        """

        self._event_data = event_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookV2Details, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookV2Details):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
